
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef pom_MSG_LIB_H
#define pom_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "pomType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  POM_MBOX_NAME                  genomInstanceName("pom")

#define  POM_MAX_RQST_SIZE              2048

#define  POM_MBOX_RQST_SIZE       \
 (BUF_SIZE(POM_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  POM_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  POM_MAX_REPLY_SIZE             872

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  POM_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(POM_MAX_REPLY_SIZE) \
   + BUF_SIZE(POM_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define POM_SETMODEL_RQST 0
#define POM_GETMODEL_RQST 1
#define POM_GETFUSIONMETHOD_RQST 2
#define POM_SETFUSIONMETHOD_RQST 3
#define POM_RUN_RQST 4
#define POM_MONITORPOSKO_RQST 5
#define POM_MONITORPOSOK_RQST 6
#define POM_MONITORMEREJECT_RQST 7
#define POM_ADDME_RQST 8
#define POM_REMOVEME_RQST 9
#define POM_SETREFME_RQST 10
#define POM_RESET_RQST 11
#define POM_ADDSE_RQST 12
#define POM_REMOVESE_RQST 13
#define POM_SETPOS_RQST 14
#define POM_GETPOS_RQST 15
#define POM_GETFRAMEPOS_RQST 16
#define POM_SETABSPOSFROMME_RQST 17
#define POM_LOG_RQST 18
#define POM_STOPLOG_RQST 19
#define POM_DISPLAYFRAME_RQST 20
#define POM_WRITESENSORPOSFILE_RQST 21
#define POM_ABORT_RQST 22


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS pomClientInit (CLIENT_ID *pClientId);

STATUS pomClientEnd (CLIENT_ID clientId);

int pomAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int pomAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int pomAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS pomSetModelRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_modelname),
					 int replyTimeOut);

extern int pomSetModelReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomSetModelRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_modelname), 
					
					int *activity, int *bilan);

extern int pomSetModelRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_modelname), 
					
					int *activity,
					int *bilan);




extern STATUS pomGetModelRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int pomGetModelReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       POM_STRING *(out_modelname),
			       int *bilan);

int pomGetModelRqstAndRcv (CLIENT_ID clientId, 
				  
				 POM_STRING *(out_modelname),
				 int *bilan);




extern STATUS pomGetFusionMethodRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int pomGetFusionMethodReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       POM_FUSION_METHOD *(out_fusionMethod),
			       int *bilan);

int pomGetFusionMethodRqstAndRcv (CLIENT_ID clientId, 
				  
				 POM_FUSION_METHOD *(out_fusionMethod),
				 int *bilan);




extern STATUS pomSetFusionMethodRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 POM_FUSION_METHOD *(in_fusionMethod),
					 int replyTimeOut);

int pomSetFusionMethodReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int pomSetFusionMethodRqstAndRcv (CLIENT_ID clientId, 
				 POM_FUSION_METHOD *(in_fusionMethod), 
				 
				 int *bilan);




extern STATUS pomRunRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 POM_ACTION *(in_mode),
					 int replyTimeOut);

int pomRunReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       POM_ACTION *(out_mode),
			       int *bilan);

int pomRunRqstAndRcv (CLIENT_ID clientId, 
				 POM_ACTION *(in_mode), 
				 POM_ACTION *(out_mode),
				 int *bilan);




extern STATUS pomMonitorPosKORqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_UNC *(in_pomUnc),
					 int replyTimeOut);

extern int pomMonitorPosKOReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomMonitorPosKORqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_UNC *(in_pomUnc), 
					
					int *activity, int *bilan);

extern int pomMonitorPosKORqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_UNC *(in_pomUnc), 
					
					int *activity,
					int *bilan);




extern STATUS pomMonitorPosOKRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_UNC *(in_pomUnc),
					 int replyTimeOut);

extern int pomMonitorPosOKReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomMonitorPosOKRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_UNC *(in_pomUnc), 
					
					int *activity, int *bilan);

extern int pomMonitorPosOKRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_UNC *(in_pomUnc), 
					
					int *activity,
					int *bilan);




extern STATUS pomMonitorMERejectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int pomMonitorMERejectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomMonitorMERejectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int pomMonitorMERejectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS pomAddMERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_ME_CREATE_DATA *(in_medata),
					 int replyTimeOut);

extern int pomAddMEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomAddMERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_ME_CREATE_DATA *(in_medata), 
					
					int *activity, int *bilan);

extern int pomAddMERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_ME_CREATE_DATA *(in_medata), 
					
					int *activity,
					int *bilan);




extern STATUS pomRemoveMERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomRemoveMEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomRemoveMERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity, int *bilan);

extern int pomRemoveMERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS pomSetRefMERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomSetRefMEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomSetRefMERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity, int *bilan);

extern int pomSetRefMERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS pomResetRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int pomResetReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomResetRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int pomResetRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS pomAddSERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_SE_CREATE_DATA *(in_sedata),
					 int replyTimeOut);

extern int pomAddSEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomAddSERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_SE_CREATE_DATA *(in_sedata), 
					
					int *activity, int *bilan);

extern int pomAddSERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_SE_CREATE_DATA *(in_sedata), 
					
					int *activity,
					int *bilan);




extern STATUS pomRemoveSERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomRemoveSEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomRemoveSERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity, int *bilan);

extern int pomRemoveSERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS pomSetPosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_SET_POS *(in_pos),
					 int replyTimeOut);

extern int pomSetPosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomSetPosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_SET_POS *(in_pos), 
					
					int *activity, int *bilan);

extern int pomSetPosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_SET_POS *(in_pos), 
					
					int *activity,
					int *bilan);




extern STATUS pomGetPosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int pomGetPosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      POM_SET_POS *(out_pos),
				      int *activity, int *bilan);


extern int pomGetPosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					POM_SET_POS *(out_pos),
					int *activity, int *bilan);

extern int pomGetPosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					POM_SET_POS *(out_pos),
					int *activity,
					int *bilan);




extern STATUS pomGetFramePosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomGetFramePosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      POM_SET_POS *(out_pos),
				      int *activity, int *bilan);


extern int pomGetFramePosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					POM_SET_POS *(out_pos),
					int *activity, int *bilan);

extern int pomGetFramePosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					POM_SET_POS *(out_pos),
					int *activity,
					int *bilan);




extern STATUS pomSetAbsPosFromMERqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomSetAbsPosFromMEReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomSetAbsPosFromMERqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity, int *bilan);

extern int pomSetAbsPosFromMERqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					
					int *activity,
					int *bilan);




extern STATUS pomLogRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_fileName),
					 int replyTimeOut);

extern int pomLogReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomLogRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_fileName), 
					
					int *activity, int *bilan);

extern int pomLogRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS pomStopLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int pomStopLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int pomStopLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS pomDisplayFrameRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING *(in_name),
					 int replyTimeOut);

extern int pomDisplayFrameReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      POM_SENSOR_POS *(out_framePos),
				      int *activity, int *bilan);


extern int pomDisplayFrameRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING *(in_name), 
					POM_SENSOR_POS *(out_framePos),
					int *activity, int *bilan);

extern int pomDisplayFrameRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING *(in_name), 
					POM_SENSOR_POS *(out_framePos),
					int *activity,
					int *bilan);




extern STATUS pomWriteSensorPosFileRqstSend (CLIENT_ID clientId, int *pRqstId,
					 POM_STRING_2 *(in_posterName_fileName),
					 int replyTimeOut);

extern int pomWriteSensorPosFileReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int pomWriteSensorPosFileRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					POM_STRING_2 *(in_posterName_fileName), 
					
					int *activity, int *bilan);

extern int pomWriteSensorPosFileRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					POM_STRING_2 *(in_posterName_fileName), 
					
					int *activity,
					int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* pom_MSG_LIB_H */

