
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef pom_TCLSERV_CLIENT_ERROR_H
#define pom_TCLSERV_CLIENT_ERROR_H

#include <server/pomError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum pom_error {
	E_pom_OK					  			= 0,

	/* module errors */
	E_pom_NO_MODEL                       = S_pom_NO_MODEL,
	E_pom_NO_SUCH_FRAME                  = S_pom_NO_SUCH_FRAME,
	E_pom_NO_FRAME_LIST                  = S_pom_NO_FRAME_LIST,
	E_pom_CANNOT_WRITE_FILE              = S_pom_CANNOT_WRITE_FILE,
	E_pom_CANNOT_OPEN_FILE               = S_pom_CANNOT_OPEN_FILE,
	E_pom_CANNOT_SET_POS                 = S_pom_CANNOT_SET_POS,
	E_pom_UNKNOWN_FRAME                  = S_pom_UNKNOWN_FRAME,
	E_pom_NO_SUCH_SE                     = S_pom_NO_SUCH_SE,
	E_pom_CANNOT_FIND_LINK               = S_pom_CANNOT_FIND_LINK,
	E_pom_NO_SUCH_ME                     = S_pom_NO_SUCH_ME,
	E_pom_CANNOT_FIND_POSTER             = S_pom_CANNOT_FIND_POSTER,
	E_pom_ME_ALREADY_EXISTS              = S_pom_ME_ALREADY_EXISTS,
	E_pom_ME_REJECTED                    = S_pom_ME_REJECTED,
	E_pom_POM_PSI_OUT                    = S_pom_POM_PSI_OUT,
	E_pom_POM_PHI_OUT                    = S_pom_POM_PHI_OUT,
	E_pom_POM_THETA_OUT                  = S_pom_POM_THETA_OUT,
	E_pom_POM_Z_OUT                      = S_pom_POM_Z_OUT,
	E_pom_POM_Y_OUT                      = S_pom_POM_Y_OUT,
	E_pom_POM_X_OUT                      = S_pom_POM_X_OUT,
	E_pom_BAD_PARAMS                     = S_pom_BAD_PARAMS,
	E_pom_NO_SUCH_FILE                   = S_pom_NO_SUCH_FILE,
	E_pom_POSTER_NOT_FOUND               = S_pom_POSTER_NOT_FOUND,
	E_pom_NOT_ENOUGH_MEMORY              = S_pom_NOT_ENOUGH_MEMORY,
	E_pom_SYNTAX_ERROR                   = S_pom_SYNTAX_ERROR,
	E_pom_NO_INSITU                      = S_pom_NO_INSITU,
	E_pom_CAREFUL_JUMP                   = S_pom_CAREFUL_JUMP,
	E_pom_CANNOT_GET_FRAMES              = S_pom_CANNOT_GET_FRAMES,
	E_pom_CANNOT_FUSE_POSITIONS          = S_pom_CANNOT_FUSE_POSITIONS,
	E_pom_CANNOT_TAKE_POSTER             = S_pom_CANNOT_TAKE_POSTER,
	E_pom_CANNOT_CREATE_POSTER           = S_pom_CANNOT_CREATE_POSTER,


	/* std errors */
	E_pom_ACTIVITY_INTERRUPTED           = S_pom_stdGenoM_ACTIVITY_INTERRUPTED,
	E_pom_TOO_MANY_ACTIVITIES            = S_pom_stdGenoM_TOO_MANY_ACTIVITIES,
	E_pom_ACTIVITY_FAILED                = S_pom_stdGenoM_ACTIVITY_FAILED,
	E_pom_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_pom_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_pom_UNKNOWN_ACTIVITY               = S_pom_stdGenoM_UNKNOWN_ACTIVITY,
	E_pom_FORBIDDEN_ACTIVITY_TRANSITION  = S_pom_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_pom_SYSTEM_ERROR                   = S_pom_stdGenoM_SYSTEM_ERROR,
	E_pom_ACTIVITY_ALREADY_ENDED         = S_pom_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_pom_WAIT_INIT_RQST                 = S_pom_stdGenoM_WAIT_INIT_RQST,
	E_pom_CONTROL_CODEL_ERROR            = S_pom_stdGenoM_CONTROL_CODEL_ERROR,
	E_pom_EXEC_TASK_SUSPENDED            = S_pom_stdGenoM_EXEC_TASK_SUSPENDED,
	E_pom_BAD_BLOCK_TYPE                 = S_pom_stdGenoM_BAD_BLOCK_TYPE,
	E_pom_BAD_POSTER_TYPE                = S_pom_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum pom_error pom_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int pom_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the pom context.
 *
 * Returns NULL in case of failure
 */
const char* pom_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
